\name{YEASTENZYME2PROBE}
\alias{YEASTENZYME2PROBE}
\title{Mappings between Enzyme Commission numbers and probe identifiers}
\description{
  YEASTENZYME2PROBE maps Enzyme Commission numbers to probe identifiers
  representing genes whose products exhibit the functions of the enzymes
  labeled by the Commission Numbers
}
\details{
  Enzyme Commission numbers are assigned by the Nomenclature Committee
  of the International Union of Biochemistry and Molecular Biology
  \url{http://www.chem.qmw.ac.uk/iubmb/enzyme/} to allow enzymes to be
  identified. 
  
  An Enzyme Commission number is of the format EC x.y.z.w, where x, y, z,
  and w are numeric numbers. In YEASTENZYME2PROBE, EC is dropped from the
  Enzyme Commission numbers.

  Enzyme Commission numbers have corresponding names that describe the
  functions of enzymes in such a way that EC x is a more general
  description than EC x.y that in turn is a more general description than
  EC x.y.z. The top level EC numbers and names are listed below:

  EC 1 oxidoreductases
  
  EC 2 transferases

  EC 3 hydrolases

  EC 4 lyases

  EC 5 isomerases

  EC 6 ligases

  The EC name for a given EC number can be viewed at
  \url{http://www.chem.qmul.ac.uk/iupac/jcbn/index.html#6} 
  
  Mappings were based on data provided by:

  KEGG:\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}. Built: Yeast Genome data are built at various time  intervals. Sources used were downloaded  Fri Jan  7 14:56:44 2005 


  Package built Fri Jan  7 16:12:38 2005
}
\references{
\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}
}
\examples{
    # Convert to a list
    xx <- as.list(YEASTENZYME2PROBE)
   if(length(xx) > 0){
       # Gets the probe ids for the first five enzyme
       #commission numbers
       xx[1:5]
       # Get the first one
       xx[[1]]
    }
}
\keyword{datasets}

